==> ukui-screensaver_3.0.1.orig.tar.gz: ukui-screensaver/i18n_ts/bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../src/authdialog.cpp" line="237"/>
        <source>Password: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="253"/>
        <source>Password Incorrect, Please try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="419"/>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="432"/>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="444"/>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="454"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="99"/>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="160"/>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="47"/>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="52"/>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="68"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="78"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="47"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="49"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <location filename="../src/lockwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="54"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="67"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.cpp" line="247"/>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../src/powermanager.cpp" line="109"/>
        <source>Lock Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="124"/>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="138"/>
        <source>Log Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="152"/>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="166"/>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="66"/>
        <source>The screensaver is active.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="68"/>
        <source>The screensaver is inactive.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="284"/>
        <source>Set as desktop wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="294"/>
        <source>Automatic switching</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <location filename="../screensaver/sleeptime.cpp" line="70"/>
        <source>You have rested:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../screensaver/main.cpp" line="55"/>
        <source>Screensaver for ukui-screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="59"/>
        <source>show on root window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="61"/>
        <source>show on window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="62"/>
        <source>window id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="40"/>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="45"/>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="136"/>
        <source>lock the screen immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="48"/>
        <source>query the status of the screen saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="131"/>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="138"/>
        <source>activated by session idle signal</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> ukui-screensaver_3.0.2.orig.tar.gz: ukui-screensaver/i18n_ts/bo.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>AuthDialog</name>
    <message>
        <location filename="../src/authdialog.cpp" line="229"/>
        <location filename="../src/authdialog.cpp" line="300"/>
        <location filename="../src/authdialog.cpp" line="305"/>
        <source>Please enter your password or enroll your fingerprint </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="310"/>
        <source>Password: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="333"/>
        <source>Authentication failure, Please try again</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="507"/>
        <source>Biometric Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="520"/>
        <source>Password Authentication</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="533"/>
        <source>Other Devices</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="543"/>
        <source>Retry</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="632"/>
        <source>Too many unsuccessful attempts,please enter password.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/authdialog.cpp" line="636"/>
        <source>Fingerprint authentication failed, you still have %1 verification opportunities</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricAuthWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="102"/>
        <source>Current device: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricauthwidget.cpp" line="168"/>
        <source>Identify failed, Please retry.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BiometricDevicesWidget</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="48"/>
        <source>Please select the biometric device</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="53"/>
        <source>Device type:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="69"/>
        <source>Device name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceswidget.cpp" line="79"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeviceType</name>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="41"/>
        <source>FingerPrint</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="43"/>
        <source>FingerVein</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="45"/>
        <source>Iris</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="47"/>
        <source>Face</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../BiometricAuth/biometricdeviceinfo.cpp" line="49"/>
        <source>VoicePrint</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KeyboardWidget</name>
    <message>
        <location filename="../VirtualKeyboard/src/keyboardwidget.ui" line="29"/>
        <source>KeyboardWidget</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <location filename="../src/lockwidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="55"/>
        <source>Date</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.ui" line="48"/>
        <source>Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.cpp" line="299"/>
        <source>SwitchUser</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/lockwidget.cpp" line="316"/>
        <source>Guest</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PowerManager</name>
    <message>
        <location filename="../src/powermanager.cpp" line="169"/>
        <source>Lock Screen</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="184"/>
        <source>Switch User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="198"/>
        <source>Log Out</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="212"/>
        <source>Restart</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="226"/>
        <source>Power Off</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="267"/>
        <source>Suspend</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/powermanager.cpp" line="289"/>
        <source>Sleep</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="76"/>
        <source>The screensaver is active.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="78"/>
        <source>The screensaver is inactive.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Screensaver</name>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="124"/>
        <source>Picture does not exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="615"/>
        <source>Set as desktop wallpaper</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/screensaver.cpp" line="625"/>
        <source>Automatic switching</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SleepTime</name>
    <message>
        <location filename="../screensaver/sleeptime.cpp" line="70"/>
        <source>You have rested:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../screensaver/main.cpp" line="61"/>
        <source>Screensaver for ukui-screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="65"/>
        <source>show on root window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="67"/>
        <source>show on window.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../screensaver/main.cpp" line="68"/>
        <source>window id</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="40"/>
        <source>Start command for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="45"/>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="149"/>
        <source>lock the screen immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="48"/>
        <source>query the status of the screen saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="51"/>
        <source>unlock the screen saver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-command.cpp" line="53"/>
        <source>show the screensaver</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="144"/>
        <source>Dialog for the ukui ScreenSaver.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="151"/>
        <source>activated by session idle signal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="153"/>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="157"/>
        <source>lock the screen and show screensaver immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ukui-screensaver-dialog.cpp" line="155"/>
        <source>show screensaver immediately</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
